@@ -16,7 +16,8 @@
 class QDialogButtonBox;
 class QLabel;
 class QLineEdit;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
     @short Dialog to allow user to configure a hyperlink.
     @author Stephen Kelly
@@ -42,7 +43,7 @@ public:
     /**
      * Destructor
      */
-    ~KLinkDialog();
+    ~KLinkDialog() override;
 
     /**
      * Returns the link text shown in the dialog
