@@ -1,29 +1,17 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPIMTEXTEDITRICHTEXTCOMPOSERCONTROLER_H
 #define KPIMTEXTEDITRICHTEXTCOMPOSERCONTROLER_H
 
-#include <QObject>
-#include "richtextcomposer.h"
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit {
+#include "richtextcomposer.h"
+#include <QObject>
+namespace KPIMTextEdit
+{
 class RichTextComposer;
 class NestedListHelper;
 class RichTextComposerImages;
@@ -36,7 +24,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerControler : public QObject
     Q_OBJECT
 public:
     explicit RichTextComposerControler(RichTextComposer *richtextComposer, QObject *parent = nullptr);
-    ~RichTextComposerControler();
+    ~RichTextComposerControler() override;
 
     Q_REQUIRED_RESULT RichTextComposer *richTextComposer() const;
 
@@ -67,9 +55,7 @@ public:
     Q_REQUIRED_RESULT QString toCleanPlainText(const QString &plainText = QString()) const;
     void addQuotes(const QString &defaultQuote);
 public Q_SLOTS:
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     void addCheckbox(bool add = true);
-#endif
     void insertHorizontalRule();
     void setHeadingLevel(int level);
     void alignLeft();
@@ -106,6 +92,7 @@ public Q_SLOTS:
     void slotAddImage();
     void slotFormatPainter(bool active);
     void ensureCursorVisibleDelayed();
+
 private:
     class RichTextComposerControlerPrivate;
     RichTextComposerControlerPrivate *const d;
