@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,13 @@
 #ifndef EMOTICONUNICODEUTILS_H
 #define EMOTICONUNICODEUTILS_H
 
+#include "kpimtextedit_export.h"
 #include <QString>
 #include <QVector>
-#include "kpimtextedit_export.h"
-namespace KPIMTextEdit {
-namespace EmoticonUnicodeUtils {
+namespace KPIMTextEdit
+{
+namespace EmoticonUnicodeUtils
+{
 struct EmoticonStruct {
     EmoticonStruct(const QString &name, const QString &code)
         : emoticonName(name)
