@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,7 +13,8 @@
 #include "kpimtextedit/plaintexteditor.h"
 #include <KSyntaxHighlighting/Repository>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextEditorCompleter;
 class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
 {
@@ -21,8 +22,10 @@ class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
 public:
     explicit InsertHtmlEditor(QWidget *parent = nullptr);
     ~InsertHtmlEditor() override;
+
 protected:
     void keyPressEvent(QKeyEvent *e) override;
+
 private:
     KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
     KSyntaxHighlighting::Repository mRepo;
