@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,13 +12,14 @@
 
 #include <QTextLength>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TableFormatDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit TableFormatDialog(QWidget *parent);
-    ~TableFormatDialog();
+    ~TableFormatDialog() override;
 
     Q_REQUIRED_RESULT int columns() const;
     Q_REQUIRED_RESULT int rows() const;
