@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "textfindreplacewidget.h"
 
+#include <KColorScheme>
 #include <KLocalizedString>
 #include <QPushButton>
-#include <KColorScheme>
 
-#include <QLineEdit>
-#include <QLabel>
-#include <QMenu>
 #include <QHBoxLayout>
+#include <QLabel>
+#include <QLineEdit>
+#include <QMenu>
 #include <QRegularExpression>
 
 using namespace KPIMTextEdit;
@@ -21,7 +21,7 @@ using namespace KPIMTextEdit;
 TextReplaceWidget::TextReplaceWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     QLabel *label = new QLabel(i18nc("Replace text", "Replace:"), this);
     lay->addWidget(label);
     const int marg1 = lay->contentsMargins().left();
@@ -59,7 +59,7 @@ void TextReplaceWidget::slotSearchStringEmpty(bool isEmpty)
 TextFindWidget::TextFindWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     const int marg1 = lay->contentsMargins().left();
     const int marg2 = lay->contentsMargins().right();
     lay->setContentsMargins(marg1, 0, marg2, 0);
@@ -82,10 +82,10 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     lay->addWidget(mFindPrevBtn);
     mFindPrevBtn->setEnabled(false);
 
-    auto *optionsBtn = new QPushButton(this);
+    auto optionsBtn = new QPushButton(this);
     optionsBtn->setText(i18n("Options"));
     optionsBtn->setToolTip(i18n("Modify search behavior"));
-    auto *optionsMenu = new QMenu(optionsBtn);
+    auto optionsMenu = new QMenu(optionsBtn);
     mCaseSensitiveAct = optionsMenu->addAction(i18n("Case sensitive"));
     mCaseSensitiveAct->setCheckable(true);
 
@@ -127,8 +127,7 @@ void TextFindWidget::setFoundMatch(bool match)
 
         KStatefulBrush bgBrush(KColorScheme::View, bgColorScheme);
 
-        styleSheet = QStringLiteral("QLineEdit{ background-color:%1 }")
-                     .arg(bgBrush.brush(mSearch).color().name());
+        styleSheet = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mSearch).color().name());
     }
 
     mSearch->setStyleSheet(styleSheet);
