@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QWidget>
 class QTimer;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
  * @short A widget that displays messages in the top-left corner.
  *
@@ -24,12 +25,7 @@ class TextMessageIndicator : public QWidget
 public:
     explicit TextMessageIndicator(QWidget *parent = nullptr);
 
-    enum Icon {
-        None,
-        Info,
-        Warning,
-        Error
-    };
+    enum Icon { None, Info, Warning, Error };
 
     void display(const QString &message, const QString &details = QString(), Icon icon = None, int durationMs = 4000);
 
