@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "texttospeechconfigwidgettest.h"
-#include "texttospeech/texttospeechconfigwidget.h"
 #include "texttospeech/abstracttexttospeechconfiginterface.h"
+#include "texttospeech/texttospeechconfigwidget.h"
 
-#include <QTest>
-#include <QSlider>
-#include <QSignalSpy>
 #include <QComboBox>
+#include <QSignalSpy>
+#include <QSlider>
+#include <QTest>
 
 TextToSpeechConfigWidgetTest::TextToSpeechConfigWidgetTest(QObject *parent)
     : QObject(parent)
@@ -24,7 +24,7 @@ TextToSpeechConfigWidgetTest::~TextToSpeechConfigWidgetTest()
 
 void TextToSpeechConfigWidgetTest::addInterface(KPIMTextEdit::TextToSpeechConfigWidget *widget)
 {
-    auto *interface = new KPIMTextEdit::AbstractTextToSpeechConfigInterface(this);
+    auto interface = new KPIMTextEdit::AbstractTextToSpeechConfigInterface(this);
     widget->setTextToSpeechConfigInterface(interface);
 }
 
@@ -43,8 +43,8 @@ void TextToSpeechConfigWidgetTest::shouldHaveDefaultValue()
 
     auto *language = textToSpeechConfigWidget.findChild<QComboBox *>(QStringLiteral("language"));
     QVERIFY(language);
-    //FIXME
-    //QVERIFY(language->count()>0);
+    // FIXME
+    // QVERIFY(language->count()>0);
 
     auto *availableEngine = textToSpeechConfigWidget.findChild<QComboBox *>(QStringLiteral("engine"));
     QVERIFY(availableEngine);
